@@ -1,5 +1,9 @@
+## ----include=FALSE------------------------------------------------------------
+# limit number of threads on OpenMP
+Sys.setenv("OMP_THREAD_LIMIT" = 2)
+
 ## ----skipNoSNPSTATS-----------------------------------------------------------
-# this vignette is not created if snpStats is not installed
+# IMPORTANT: this vignette is not created if snpStats is not installed
 if (!require("snpStats")) {
   knitr::opts_chunk$set(eval = FALSE)
 }
